
## Spiri cameras project installation 

```bash
LINUX_FOR_TEGRA=<Linux_for_Tegra/ path>
cd $LINUX_FOR_TEGRA

# Clone the repository to the workspace
git clone --recurse-submodules  https://git.spirirobotics.com/dchvs/spiri-project.git
cd spiri-project
git checkout 4.4.1/tx2-cti/camera-driver-dev
git submodule update --init --recursive --remote

# Install the CTI BSP
cd CTI-L4T/
sudo ./install.sh

# Install the Jetpack+CTI 4.4.1 and Driver MT9M021 to source/ directory
cd $LINUX_FOR_TEGRA
mkdir source/ && cd source/
cp -r ../spiri-project/Jetpack/* .
cp -r ../spiri-project/li-mt9m021/ .

# Compile the sources
cd $LINUX_FOR_TEGRA
mkdir -p builds/build_<this build name> && cd builds/build_<this build name>

mkdir build modules
make -C ../../source/kernel/kernel-4.9/ ARCH=arm64 O=$PWD/build/ tegra_defconfig
make -C ../../source/kernel/kernel-4.9/ ARCH=arm64 O=$PWD/build/ menuconfig
make -C ../../source/kernel/kernel-4.9/ ARCH=arm64 O=$PWD/build/ CROSS_COMPILE=${CROSS_COMPILE} -j8 --output-sync=target zImage dtbs modules
make -C ../../source/kernel/kernel-4.9/ ARCH=arm64 O=$PWD/build/ modules_install INSTALL_MOD_PATH=$PWD/modules 
```

## Flash the Spiri MU
```bash
# Backup the default Kernel
cp  -r ../../kernel/dtb/  ../../kernel/backup_dtb/
cp  ../../kernel/Image  ../../kernel/backup_Image
sudo mv  ../../rootfs/lib/modules/4.9.140-tegra/   ../../rootfs/lib/modules/backup_4.9.140-tegra/

# Install the Kernel
cp build/arch/arm64/boot/dts/* ../../kernel/dtb/ 
cp build/arch/arm64/boot/Image ../../kernel/
sudo make -C ../../source/kernel/kernel-4.9/ ARCH=arm64 O=$PWD/build/ modules_install INSTALL_MOD_PATH=$PWD/../../rootfs/

# Flash the Spiri MU
cd $LINUX_FOR_TEGRA
sudo ./flash.sh jetson-tx2 mmcblk0p1
```

## Capture test
```bash
# Sender endpoint
gst-launch-1.0 nvarguscamerasrc ! 'video/x-raw(memory:NVMM), width=(int)1280, height=(int)720, format=(string)NV12,framerate=(fraction)30/1' ! omxh264enc control-rate=2 bitrate=8000000 ! 'video/x-h264, stream-format=(string)byte-stream' ! h264parse ! rtph264pay mtu=1400 ! udpsink host=$HOST_IP port=5000 sync=false async=false

# Receiver endpoint
gst-launch-1.0 udpsrc port=5000 ! "application/x-rtp,media=(string)video,payload=(int)96,clock-rate=(int)90000,encoding-name=(string)H264" ! rtph264depay ! queue ! avdec_h264 ! xvimagesink sync=true async=false
```

